@@ -12,6 +12,7 @@ from instagrapi.mixins.comment import CommentMixin
 from instagrapi.mixins.direct import DirectMixin
 from instagrapi.mixins.fbsearch import FbSearchMixin
 from instagrapi.mixins.hashtag import HashtagMixin
+from instagrapi.mixins.highlight import HighlightMixin
 from instagrapi.mixins.igtv import DownloadIGTVMixin, UploadIGTVMixin
 from instagrapi.mixins.insights import InsightsMixin
 from instagrapi.mixins.location import LocationMixin
@@ -39,6 +40,7 @@ class Client(
     ProfilePublicMixin,
     LoginMixin,
     FbSearchMixin,
+    HighlightMixin,
     DownloadPhotoMixin,
     UploadPhotoMixin,
     DownloadVideoMixin,
