@@ -68,6 +68,7 @@ class PreLoginFlowMixin:
             "client_contact_points": "[{\"type\":\"omnistring\",\"value\":\"%s\",\"source\":\"last_login_attempt\"}]" % self.username,
             "phone_id": self.phone_id,
             "usages": '["account_recovery_omnibox"]',
+            "logged_in_user_ids": "[]",  # "[\"123456789\",\"987654321\"]",
             "device_id": self.uuid,
         }
         # if login is False:
@@ -291,6 +292,10 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
         self.set_locale(self.settings.get("locale", self.locale))
         self.set_country(self.settings.get("country", self.country))
         self.mid = self.settings.get("mid", self.cookie_dict.get("mid"))
+        # init headers
+        headers = self.base_headers
+        headers.update({'Authorization': self.authorization})
+        self.private.headers.update(headers)
         return True
 
     def login_by_sessionid(self, sessionid: str) -> bool:
@@ -365,18 +370,16 @@ class LoginMixin(PreLoginFlowMixin, PostLoginFlowMixin):
             self.logger.warning('Ignore 429: Continue login')
             # The instagram application ignores this error
             # and continues to log in (repeat this behavior)
-            pass
         enc_password = self.password_encrypt(password)
         data = {
             "jazoest": generate_jazoest(self.phone_id),
-            # "country_codes": "[{\"country_code\":\"7\",\"source\":[\"default\"]}]",
+            "country_codes": "[{\"country_code\":\"7\",\"source\":[\"default\"]}]",
             "phone_id": self.phone_id,
             "enc_password": enc_password,
-            # "_csrftoken": self.token,
             "username": username,
             "adid": self.advertising_id,
             "guid": self.uuid,
-            "device_id": self.uuid,
+            "device_id": self.android_device_id,
             "google_tokens": "[]",
             "login_attempt_count": "0"
         }
